Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: cc/trees/layer_tree_host.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/trees/channel_main.h ('k') | cc/trees/layer_tree_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/trees/layer_tree_host.h
diff --git a/cc/trees/layer_tree_host.h b/cc/trees/layer_tree_host.h
index 5f9633532b1afdd1e0e530c5aac7897b374d4158..3fde9f1ece4455decf0900f35fa8fc664d93b74b 100644
--- a/cc/trees/layer_tree_host.h
+++ b/cc/trees/layer_tree_host.h
@@ -31,7 +31,7 @@
#include "cc/input/top_controls_state.h"
#include "cc/layers/layer_collections.h"
#include "cc/layers/layer_list_iterator.h"
-#include "cc/output/output_surface.h"
+#include "cc/output/compositor_frame_sink.h"
#include "cc/output/swap_promise.h"
#include "cc/resources/resource_format.h"
#include "cc/trees/compositor_mode.h"
@@ -153,8 +153,9 @@ class CC_EXPORT LayerTreeHost : public LayerTreeHostInterface {
void SetHasGpuRasterizationTrigger(bool has_trigger) override;
void SetVisible(bool visible) override;
bool IsVisible() const override;
- void SetOutputSurface(std::unique_ptr<OutputSurface> output_surface) override;
- std::unique_ptr<OutputSurface> ReleaseOutputSurface() override;
+ void SetCompositorFrameSink(
+ std::unique_ptr<CompositorFrameSink> compositor_frame_sink) override;
+ std::unique_ptr<CompositorFrameSink> ReleaseCompositorFrameSink() override;
void SetNeedsAnimate() override;
void SetNeedsUpdateLayers() override;
void SetNeedsCommit() override;
@@ -192,12 +193,12 @@ class CC_EXPORT LayerTreeHost : public LayerTreeHostInterface {
void FinishCommitOnImplThread(LayerTreeHostImpl* host_impl);
void WillCommit();
void CommitComplete();
- void RequestNewOutputSurface();
- void DidInitializeOutputSurface();
- void DidFailToInitializeOutputSurface();
+ void RequestNewCompositorFrameSink();
+ void DidInitializeCompositorFrameSink();
+ void DidFailToInitializeCompositorFrameSink();
virtual std::unique_ptr<LayerTreeHostImpl> CreateLayerTreeHostImpl(
LayerTreeHostImplClient* client);
- void DidLoseOutputSurface();
+ void DidLoseCompositorFrameSink();
void DidCommitAndDrawFrame() { client_->DidCommitAndDrawFrame(); }
void DidCompleteSwapBuffers() { client_->DidCompleteSwapBuffers(); }
bool UpdateLayers();
@@ -350,13 +351,13 @@ class CC_EXPORT LayerTreeHost : public LayerTreeHostInterface {
SwapPromiseManager swap_promise_manager_;
- // |current_output_surface_| can't be updated until we've successfully
- // initialized a new output surface. |new_output_surface_| contains the
- // new output surface that is currently being initialized. If initialization
- // is successful then |new_output_surface_| replaces
- // |current_output_surface_|.
- std::unique_ptr<OutputSurface> new_output_surface_;
- std::unique_ptr<OutputSurface> current_output_surface_;
+ // |current_compositor_frame_sink_| can't be updated until we've successfully
+ // initialized a new CompositorFrameSink. |new_compositor_frame_sink_|
+ // contains the new CompositorFrameSink that is currently being initialized.
+ // If initialization is successful then |new_compositor_frame_sink_| replaces
+ // |current_compositor_frame_sink_|.
+ std::unique_ptr<CompositorFrameSink> new_compositor_frame_sink_;
+ std::unique_ptr<CompositorFrameSink> current_compositor_frame_sink_;
const LayerTreeSettings settings_;
LayerTreeDebugState debug_state_;
« no previous file with comments | « cc/trees/channel_main.h ('k') | cc/trees/layer_tree_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698